Open Images and Other Files

Open a local image or auxiliary file:
Filename:
Format: image catalog cmap region session

Retrieve and open a remote image:
URL:
Method: proxy server cgi proxy CORS server

Local files: JS9 can load FITS files, jpeg or png images, catalogs, colormaps, region files, and session files.

Remote files via proxy: URLs from servers without CORS can't display directly in JS9. If the JS9 server is set up as a proxy server, data will be stored temporarily (allowing server-side analysis). Otherwise, the cgi proxy on https://js9.si.edu will retrieve the data for display only.

Remote files using a CORS-enabled server: URLs from servers that support CORS (e.g., Dropbox) will display directly in JS9 (but without server-side analysis).